@@ -1,4 +1,4 @@
-/* $Id: nano.c,v 1.144.2.21 2001/12/14 05:57:10 astyanax Exp $ */
+/* $Id: nano.c,v 1.144.2.25 2002/01/16 00:54:35 astyanax Exp $ */
 /**************************************************************************
  *   nano.c                                                               *
  *                                                                        *
@@ -479,6 +479,9 @@ void version(void)
 #ifdef DISABLE_WRAPPING
     printf(" --disable-wrapping");
 #endif
+#ifdef DISABLE_ROOTWRAP
+    printf(" --disable-wrapping-as-root");
+#endif
 #ifdef USE_SLANG
     printf(" --with-slang");
 #endif
@@ -898,7 +901,6 @@ void do_wrap(filestruct * inptr, char input_char)
 		while ((inptr->next->data[i] == ' ' 
 	    		|| inptr->next->data[i] == '\t')) {
 		    i++;
-		    right++;
 		}			
 	    }
 	    down = 1;
@@ -951,7 +953,6 @@ void do_wrap(filestruct * inptr, char input_char)
 		while ((inptr->next->data[i] == ' ' 
 	    		|| inptr->next->data[i] == '\t')) {
 		    i++;
-		    right++;
 		}			
 	    }
 
@@ -1058,6 +1059,7 @@ void do_wrap(filestruct * inptr, char input_char)
 		    extra++;
 		    spc++;
 		    totsize++;
+		    right++;
 		}
 		t = nmalloc(strlen(temp->data) + extra + 1);
 		strncpy(t, inptr->data, extra);
@@ -1297,27 +1299,36 @@ int do_int_spell_fix(char *word)
 
     edit_update(fileage, TOP);
 
-    /* make sure word is still mis-spelt (i.e. when multi-errors) */
-    if (findnextstr(TRUE, fileage, beginx_top, prevanswer) != NULL)
-    {
-	do_replace_highlight(TRUE, prevanswer);
+    while (1) {
 
-	/* allow replace word to be corrected */
-	i = statusq(0, spell_list, SPELL_LIST_LEN, last_replace, 
+	/* make sure word is still mis-spelt (i.e. when multi-errors) */
+	if (findnextstr(TRUE, fileage, beginx_top, prevanswer) != NULL) {
+
+	    /* find wholewords only */
+	    if (!is_whole_word(current_x, current, prevanswer))
+		continue;
+
+	    do_replace_highlight(TRUE, prevanswer);
+
+	    /* allow replace word to be corrected */
+	    i = statusq(0, spell_list, SPELL_LIST_LEN, last_replace,
 		_("Edit a replacement"));
 
-	do_replace_highlight(FALSE, prevanswer);
+	    do_replace_highlight(FALSE, prevanswer);
 
-	/* start from the start of this line again */
-	current = fileage;
-	current_x = beginx_top;
+	    /* start from the start of this line again */
+	    current = fileage;
+	    current_x = beginx_top;
 
-	search_last_line = FALSE;
+	    search_last_line = FALSE;
 
-	if (strcmp(prevanswer,answer) != 0) {
-	   j = i;
-	   do_replace_loop(prevanswer, fileage, &beginx_top, TRUE, &j);
+	    if (strcmp(prevanswer,answer) != 0) {
+		j = i;
+		do_replace_loop(prevanswer, fileage, &beginx_top, TRUE, &j);
+	    }
 	}
+
+	break;
     }
 
     /* restore the search/replace strings */
@@ -1684,6 +1695,9 @@ RETSIGTYPE do_suspend(int signal)
     printf("\n\n\n\n\nUse \"fg\" to return to nano\n");
     fflush(stdout);
 
+    /* Restore the terminal settings for the disabled keys */
+    tcsetattr(0, TCSANOW, &oldterm);
+
     /* We used to re-enable the default SIG_DFL and raise SIGTSTP, but 
 	then we could be (and were) interrupted in the middle of the call.
 	So we do it the mutt way instead */
@@ -2451,6 +2465,10 @@ int main(int argc, char *argv[])
 	    filename = mallocstrcpy(filename, argv[optind]);
     }
 
+#ifdef DISABLE_ROOTWRAP
+    if (geteuid() == 0)
+	SET(NO_WRAP);
+#endif
 
     /* First back up the old settings so they can be restored, duh */
     tcgetattr(0, &oldterm);
