@@ -1,4 +1,4 @@
-/* $Id: search.c,v 1.56.2.6 2001/10/24 11:42:21 astyanax Exp $ */
+/* $Id: search.c,v 1.56.2.8 2002/01/14 03:37:31 astyanax Exp $ */
 /**************************************************************************
  *   search.c                                                             *
  *                                                                        *
@@ -212,6 +212,20 @@ void not_found_msg(char *str)
     }
 }
 
+int is_whole_word(int curr_pos, filestruct *fileptr, char *searchword)
+{
+    /* start of line or previous character not a letter */
+    if ((curr_pos < 1) || (!isalpha((int) fileptr->data[curr_pos-1])))
+
+	/* end of line or next character not a letter */
+	if (((curr_pos + strlen(searchword)) == strlen(fileptr->data))
+	    || (!isalpha((int) fileptr->data[curr_pos + strlen(searchword)])))
+
+	    return TRUE;
+
+    return FALSE;
+}
+
 filestruct *findnextstr(int quiet, filestruct * begin, int beginx,
 			char *needle)
 {
@@ -271,7 +285,7 @@ filestruct *findnextstr(int quiet, filestruct * begin, int beginx,
 	current_x_find++;
 
     /* Ensure we haven't wrapped around again! */
-    if ((search_last_line) && (current_x_find >= beginx)) {
+    if ((search_last_line) && (current_x_find > beginx)) {
 	if (!quiet)
 	    not_found_msg(needle);
 	return NULL;
@@ -523,21 +537,8 @@ int do_replace_loop(char *prevanswer, filestruct *begin, int *beginx,
 	    break;
 
 	/* Make sure only whole words are found */
-	if (wholewords)
-	{
-	    /* start of line or previous character not a letter */
-	    if ((current_x == 0) || (!isalpha((int) fileptr->data[current_x-1])))
-	    {
-		/* end of line or next character not a letter */
-		if (((current_x + strlen(prevanswer)) == strlen(fileptr->data))
-			|| (!isalpha((int) fileptr->data[current_x + strlen(prevanswer)])))
-		    ;
-		else
-		    continue;
-	    }
-	    else
-		continue;
-	}
+	if ((wholewords) && (!is_whole_word(current_x, fileptr, prevanswer)))
+	    continue;
 
 	/* If we're here, we've found the search string */
 	if (!replaceall) {
